@@ -92,7 +92,7 @@ use strict; use warnings; use warnings FATAL => 'uninitialized';
            "bless", "dbmclose", "dbmopen", "package", "ref", "tie", "tied", "untie", "use"
 
        Low-level socket functions
-           "accept", "bind", "connect", "getpeername", "getsockname", "getsockopt", "lis
+           "accept", "bind", "connect", "getpeername", "getsockname", "getsockopt", "lis­
            ten", "recv", "send", "setsockopt", "shutdown", "socket", "socketpair"
 
        System V interprocess communication functions
@@ -101,13 +101,13 @@ use strict; use warnings; use warnings FATAL => 'uninitialized';
 
        Fetching user and group info
            "endgrent", "endhostent", "endnetent", "endpwent", "getgrent", "getgrgid",
-           "getgrnam", "getlogin", "getpwent", "getpwnam", "getpwuid", "setgrent", "setp
+           "getgrnam", "getlogin", "getpwent", "getpwnam", "getpwuid", "setgrent", "setp­
            went"
 
        Fetching network info
            "endprotoent", "endservent", "gethostbyaddr", "gethostbyname", "gethostent",
-           "getnetbyaddr", "getnetbyname", "getnetent", "getprotobyname", "getprotobynum
-           ber", "getprotoent", "getservbyname", "getservbyport", "getservent", "sethos
+           "getnetbyaddr", "getnetbyname", "getnetent", "getprotobyname", "getprotobynum­
+           ber", "getprotoent", "getservbyname", "getservbyport", "getservent", "sethos­
            tent", "setnetent", "setprotoent", "setservent"
 
        Time-related functions
@@ -120,7 +120,7 @@ use strict; use warnings; use warnings FATAL => 'uninitialized';
            "use"
 END
   ;
-    $txt=~ s/(\w)[-]\s*(\w)/$1$2/sg;# careful: the - are two different chars.
+    $txt=~ s/(\w)[-­]\s*(\w)/$1$2/sg;# careful: the -­ are two different chars.
     #print $txt;
     my @corefuncs= grep {
         length($_)>=3
